@@ -1,4 +1,4 @@
-#include "pysam.h"
+#include "bcftools.pysam.h"
 
 /*  convert.c -- functions for converting between VCF/BCF and related formats.
 
@@ -213,7 +213,7 @@ static void process_info(convert_t *convert, bcf1_t *line, fmt_t *fmt, int isamp
             case BCF_BT_INT32: if ( info->v1.i==bcf_int32_missing ) kputc('.', str); else kputw(info->v1.i, str); break;
             case BCF_BT_FLOAT: if ( bcf_float_is_missing(info->v1.f) ) kputc('.', str); else kputd(info->v1.f, str); break;
             case BCF_BT_CHAR:  kputc(info->v1.i, str); break;
-            default: fprintf(pysam_stderr,"todo: type %d\n", info->type); exit(1); break;
+            default: fprintf(bcftools_stderr,"todo: type %d\n", info->type); exit(1); break;
         }
     }
     else if ( fmt->subscript >=0 )
@@ -234,7 +234,7 @@ static void process_info(convert_t *convert, bcf1_t *line, fmt_t *fmt, int isamp
             case BCF_BT_INT16: BRANCH(int16_t, val==bcf_int16_missing, val==bcf_int16_vector_end, kputw(val, str)); break;
             case BCF_BT_INT32: BRANCH(int32_t, val==bcf_int32_missing, val==bcf_int32_vector_end, kputw(val, str)); break;
             case BCF_BT_FLOAT: BRANCH(float,   bcf_float_is_missing(val), bcf_float_is_vector_end(val), kputd(val, str)); break;
-            default: fprintf(pysam_stderr,"todo: type %d\n", info->type); exit(1); break;
+            default: fprintf(bcftools_stderr,"todo: type %d\n", info->type); exit(1); break;
         }
         #undef BRANCH
     }
@@ -1015,7 +1015,7 @@ static fmt_t *register_tag(convert_t *convert, int type, char *key, int is_gtf)
             else if ( id>=0 && bcf_hdr_idinfo_exists(convert->header,BCF_HL_INFO,id) )
             {
                 fmt->type = T_INFO;
-                fprintf(pysam_stderr,"Warning: Assuming INFO/%s\n", key);
+                fprintf(bcftools_stderr,"Warning: Assuming INFO/%s\n", key);
             }
         }
     }
@@ -1199,7 +1199,7 @@ convert_t *convert_init(bcf_hdr_t *hdr, int *samples, int nsamples, const char *
     char *p = convert->format_str;
     while ( *p )
     {
-        //fprintf(pysam_stderr,"<%s>\n", p);
+        //fprintf(bcftools_stderr,"<%s>\n", p);
         switch (*p)
         {
             case '[': is_gtf = 1; p++; break;
