@@ -1,4 +1,4 @@
-#include "pysam.h"
+#include "samtools.pysam.h"
 
 /*  bam_lpileup.c -- lplbuf routines.
 
@@ -31,6 +31,7 @@ DEALINGS IN THE SOFTWARE.  */
 #include <assert.h>
 #include "bam_plbuf.h"
 #include "bam_lpileup.h"
+#include "samtools.h"
 #include <htslib/ksort.h>
 
 #define TV_GAP 2
@@ -181,14 +182,14 @@ static int tview_func(uint32_t tid, uint32_t pos, int n, const bam_pileup1_t *pl
     }
     tv->n_pre = l;
 /*
-    fprintf(pysam_stderr, "%d\t", pos+1);
+    fprintf(samtools_stderr, "%d\t", pos+1);
     for (i = 0; i < n; ++i) {
         const bam_pileup1_t *p = pl + i;
-        if (p->is_head) fprintf(pysam_stderr, "^");
-        if (p->is_tail) fprintf(pysam_stderr, "$");
-        fprintf(pysam_stderr, "%d,", p->level);
+        if (p->is_head) fprintf(samtools_stderr, "^");
+        if (p->is_tail) fprintf(samtools_stderr, "$");
+        fprintf(samtools_stderr, "%d,", p->level);
     }
-    fprintf(pysam_stderr, "\n");
+    fprintf(samtools_stderr, "\n");
 */
     return 0;
 }
