@@ -1,4 +1,4 @@
-#include "pysam.h"
+#include "samtools.pysam.h"
 
 /*  bam_mate.c -- fix mate pairing information and clean up flags.
 
@@ -220,8 +220,39 @@ static int sync_mate(bam1_t* a, bam1_t* b)
     return 0;
 }
 
+
+static uint32_t calc_mate_score(bam1_t *b)
+{
+    uint32_t score = 0;
+    uint8_t  *qual = bam_get_qual(b);
+    int i;
+
+    for (i = 0; i < b->core.l_qseq; i++) {
+        if (qual[i] >= 15) score += qual[i];
+    }
+
+    return score;
+}
+
+
+static int add_mate_score(bam1_t *src, bam1_t *dest)
+{
+    uint8_t *data_ms;
+    uint32_t mate_score = calc_mate_score(src);
+
+    if ((data_ms = bam_aux_get(dest, "ms")) != NULL) {
+        bam_aux_del(dest, data_ms);
+    }
+
+    if (bam_aux_append(dest, "ms", 'i', sizeof(uint32_t), (uint8_t*)&mate_score) == -1) {
+        return -1;
+    }
+
+    return 0;
+}
+
 // currently, this function ONLY works if each read has one hit
-static int bam_mating_core(samFile* in, samFile* out, int remove_reads, int proper_pair_check, int add_ct)
+static int bam_mating_core(samFile *in, samFile *out, int remove_reads, int proper_pair_check, int add_ct, int do_mate_scoring)
 {
     bam_hdr_t *header;
     bam1_t *b[2] = { NULL, NULL };
@@ -231,7 +262,7 @@ static int bam_mating_core(samFile* in, samFile* out, int remove_reads, int prop
     str.l = str.m = 0; str.s = 0;
     header = sam_hdr_read(in);
     if (header == NULL) {
-        fprintf(pysam_stderr, "[bam_mating_core] ERROR: Couldn't read header\n");
+        fprintf(samtools_stderr, "[bam_mating_core] ERROR: Couldn't read header\n");
         return 1;
     }
     // Accept unknown, unsorted, or queryname sort order, but error on coordinate sorted.
@@ -242,7 +273,7 @@ static int bam_mating_core(samFile* in, samFile* out, int remove_reads, int prop
         // Looking for SO:coordinate within the @HD line only
         // (e.g. must ignore in a @CO comment line later in header)
         if ((p != 0) && (p < q)) {
-            fprintf(pysam_stderr, "[bam_mating_core] ERROR: Coordinate sorted, require grouped/sorted by queryname.\n");
+            fprintf(samtools_stderr, "[bam_mating_core] ERROR: Coordinate sorted, require grouped/sorted by queryname.\n");
             goto fail;
         }
     }
@@ -297,6 +328,13 @@ static int bam_mating_core(samFile* in, samFile* out, int remove_reads, int prop
                     cur->core.flag &= ~BAM_FPROPER_PAIR;
                 }
 
+                if (do_mate_scoring) {
+                    if ((add_mate_score(pre, cur) == -1) || (add_mate_score(cur, pre) == -1)) {
+                        fprintf(samtools_stderr, "[bam_mating_core] ERROR: unable to add mate score.\n");
+                        goto fail;
+                    }
+                }
+
                 // Write out result
                 if ( !remove_reads ) {
                     if (sam_write1(out, header, pre) < 0) goto write_fail;
@@ -363,13 +401,14 @@ void usage(FILE* where)
 "Options:\n"
 "  -r           Remove unmapped reads and secondary alignments\n"
 "  -p           Disable FR proper pair check\n"
-"  -c           Add template cigar ct tag\n");
+"  -c           Add template cigar ct tag\n"
+"  -m           Add mate score tag\n");
 
     sam_global_opt_help(where, "-.O..@");
 
     fprintf(where,
 "\n"
-"As elsewhere in samtools, use '-' as the filename for stdin/pysam_stdout. The input\n"
+"As elsewhere in samtools, use '-' as the filename for stdin/samtools_stdout. The input\n"
 "file must be grouped by read name (e.g. sorted by name). Coordinated sorted\n"
 "input is not accepted.\n");
 }
@@ -378,7 +417,7 @@ int bam_mating(int argc, char *argv[])
 {
     htsThreadPool p = {NULL, 0};
     samFile *in = NULL, *out = NULL;
-    int c, remove_reads = 0, proper_pair_check = 1, add_ct = 0, res = 1;
+    int c, remove_reads = 0, proper_pair_check = 1, add_ct = 0, res = 1, mate_score = 0;
     sam_global_args ga = SAM_GLOBAL_ARGS_INIT;
     char wmode[3] = {'w', 'b', 0};
     static const struct option lopts[] = {
@@ -387,18 +426,19 @@ int bam_mating(int argc, char *argv[])
     };
 
     // parse args
-    if (argc == 1) { usage(pysam_stdout); return 0; }
-    while ((c = getopt_long(argc, argv, "rpcO:@:", lopts, NULL)) >= 0) {
+    if (argc == 1) { usage(samtools_stdout); return 0; }
+    while ((c = getopt_long(argc, argv, "rpcmO:@:", lopts, NULL)) >= 0) {
         switch (c) {
             case 'r': remove_reads = 1; break;
             case 'p': proper_pair_check = 0; break;
             case 'c': add_ct = 1; break;
+            case 'm': mate_score = 1; break;
             default:  if (parse_sam_global_opt(c, optarg, lopts, &ga) == 0) break;
                       /* else fall-through */
-            case '?': usage(pysam_stderr); goto fail;
+            case '?': usage(samtools_stderr); goto fail;
         }
     }
-    if (optind+1 >= argc) { usage(pysam_stderr); goto fail; }
+    if (optind+1 >= argc) { usage(samtools_stderr); goto fail; }
 
     // init
     if ((in = sam_open_format(argv[optind], "rb", &ga.in)) == NULL) {
@@ -413,7 +453,7 @@ int bam_mating(int argc, char *argv[])
 
     if (ga.nthreads > 0) {
         if (!(p.pool = hts_tpool_init(ga.nthreads))) {
-            fprintf(pysam_stderr, "Error creating thread pool\n");
+            fprintf(samtools_stderr, "Error creating thread pool\n");
             goto fail;
         }
         hts_set_opt(in,  HTS_OPT_THREAD_POOL, &p);
@@ -421,12 +461,12 @@ int bam_mating(int argc, char *argv[])
     }
 
     // run
-    res = bam_mating_core(in, out, remove_reads, proper_pair_check, add_ct);
+    res = bam_mating_core(in, out, remove_reads, proper_pair_check, add_ct, mate_score);
 
     // cleanup
     sam_close(in);
     if (sam_close(out) < 0) {
-        fprintf(pysam_stderr, "[bam_mating] error while closing output file\n");
+        fprintf(samtools_stderr, "[bam_mating] error while closing output file\n");
         res = 1;
     }
 
