@@ -40,9 +40,11 @@ void setup_test_1(bam_hdr_t** hdr_in)
 }
 
 bool check_test_1(const bam_hdr_t* hdr) {
-    const char *test1_res =
+    char test1_res[200];
+    snprintf(test1_res, 199,
     "@HD\tVN:1.4\n"
-    "@SQ\tSN:blah\n";
+    "@SQ\tSN:blah\n"
+    "@PG\tID:samtools\tPN:samtools\tVN:%s\tCL:test_filter_header_rg foo bar baz\n", samtools_version());
 
     if (strcmp(hdr->text, test1_res)) {
         return false;
@@ -62,10 +64,12 @@ void setup_test_2(bam_hdr_t** hdr_in)
 }
 
 bool check_test_2(const bam_hdr_t* hdr) {
-    const char *test2_res =
+    char test2_res[200];
+    snprintf(test2_res, 199,
     "@HD\tVN:1.4\n"
     "@SQ\tSN:blah\n"
-    "@RG\tID:fish\n";
+    "@RG\tID:fish\n"
+    "@PG\tID:samtools\tPN:samtools\tVN:%s\tCL:test_filter_header_rg foo bar baz\n", samtools_version());
 
     if (strcmp(hdr->text, test2_res)) {
         return false;
@@ -73,7 +77,7 @@ bool check_test_2(const bam_hdr_t* hdr) {
     return true;
 }
 
-int main(int argc, char**argv)
+int main(int argc, char *argv[])
 {
     // test state
     const int NUM_TESTS = 2;
@@ -82,6 +86,8 @@ int main(int argc, char**argv)
     int failure = 0;
 
     int getopt_char;
+    char *test_argv[] = { "test_filter_header_rg", "foo\tbar", "baz" };
+    char *arg_list = stringify_argv(3, test_argv);
     while ((getopt_char = getopt(argc, argv, "v")) != -1) {
         switch (getopt_char) {
             case 'v':
@@ -108,7 +114,7 @@ int main(int argc, char**argv)
     bam_hdr_t* hdr1;
     const char* id_to_keep_1 = "1#2.3";
     setup_test_1(&hdr1);
-    if (verbose > 1) {
+    if (verbose > 0) {
         printf("hdr1\n");
         dump_hdr(hdr1);
     }
@@ -116,11 +122,11 @@ int main(int argc, char**argv)
 
     // test
     xfreopen(tempfname, "w", stderr); // Redirect stderr to pipe
-    bool result_1 = filter_header_rg(hdr1, id_to_keep_1);
+    bool result_1 = filter_header_rg(hdr1, id_to_keep_1, arg_list);
     fclose(stderr);
 
     if (verbose) printf("END RUN test 1\n");
-    if (verbose > 1) {
+    if (verbose > 0) {
         printf("hdr1\n");
         dump_hdr(hdr1);
     }
@@ -147,7 +153,7 @@ int main(int argc, char**argv)
     bam_hdr_t* hdr2;
     const char* id_to_keep_2 = "fish";
     setup_test_2(&hdr2);
-    if (verbose > 1) {
+    if (verbose > 0) {
         printf("hdr2\n");
         dump_hdr(hdr2);
     }
@@ -155,11 +161,11 @@ int main(int argc, char**argv)
 
     // test
     xfreopen(tempfname, "w", stderr); // Redirect stderr to pipe
-    bool result_2 = filter_header_rg(hdr2, id_to_keep_2);
+    bool result_2 = filter_header_rg(hdr2, id_to_keep_2, arg_list);
     fclose(stderr);
 
     if (verbose) printf("END RUN test 2\n");
-    if (verbose > 1) {
+    if (verbose > 0) {
         printf("hdr2\n");
         dump_hdr(hdr2);
     }
@@ -185,6 +191,7 @@ int main(int argc, char**argv)
 
     // Cleanup
     free(res.s);
+    free(arg_list);
     remove(tempfname);
     if (failure > 0)
         fprintf(orig_stderr, "%d failures %d successes\n", failure, success);
