@@ -1,26 +1,32 @@
 import os
 import pysam
 import unittest
+import json
 import collections
+import string
 import copy
 import array
 
-from TestUtils import checkFieldEqual
+from TestUtils import checkFieldEqual, BAM_DATADIR, get_temp_filename, get_temp_context, IS_PYTHON3
 
 
-SAMTOOLS = "samtools"
-WORKDIR = "pysam_test_work"
-DATADIR = "pysam_data"
-
+if IS_PYTHON3:
+    maketrans = str.maketrans
+else:
+    maketrans = string.maketrans
 
 class ReadTest(unittest.TestCase):
 
-    def buildRead(self):
+    def build_read(self):
         '''build an example read.'''
 
-        a = pysam.AlignedSegment()
+        header = pysam.AlignmentHeader.from_references(
+            ["chr1", "chr2"],
+            [10000000, 10000000])
+        
+        a = pysam.AlignedSegment(header)
         a.query_name = "read_12345"
-        a.query_sequence = "ACGT" * 10
+        a.query_sequence = "ATGC" * 10
         a.flag = 0
         a.reference_id = 0
         a.reference_start = 20
@@ -30,7 +36,6 @@ class ReadTest(unittest.TestCase):
         a.next_reference_start = 200
         a.template_length = 167
         a.query_qualities = pysam.qualitystring_to_array("1234") * 10
-        # todo: create tags
         return a
 
 
@@ -41,10 +46,12 @@ class TestAlignedSegment(ReadTest):
     '''
 
     def testEmpty(self):
+
         a = pysam.AlignedSegment()
         self.assertEqual(a.query_name, None)
         self.assertEqual(a.query_sequence, None)
-        self.assertEqual(pysam.qualities_to_qualitystring(a.query_qualities), None)
+        self.assertEqual(pysam.qualities_to_qualitystring(
+            a.query_qualities), None)
         self.assertEqual(a.flag, 0)
         self.assertEqual(a.reference_id, -1)
         self.assertEqual(a.mapping_quality, 0)
@@ -53,7 +60,7 @@ class TestAlignedSegment(ReadTest):
         self.assertEqual(a.next_reference_id, -1)
         self.assertEqual(a.next_reference_start, -1)
         self.assertEqual(a.template_length, 0)
-
+        
     def testStrOfEmptyRead(self):
         a = pysam.AlignedSegment()
         s = str(a)
@@ -70,8 +77,8 @@ class TestAlignedSegment(ReadTest):
 
     def testCompare(self):
         '''check comparison functions.'''
-        a = self.buildRead()
-        b = self.buildRead()
+        a = self.build_read()
+        b = self.build_read()
 
         self.assertEqual(0, a.compare(b))
         self.assertEqual(0, b.compare(a))
@@ -80,24 +87,24 @@ class TestAlignedSegment(ReadTest):
         self.assertFalse(a != b)
         self.assertFalse(b != a)
 
-        b.tid = 2
+        b.tid = 1
         self.assertFalse(a == b)
         self.assertFalse(b == a)
         self.assertTrue(a != b)
         self.assertTrue(b != a)
 
     def testHashing(self):
-        a = self.buildRead()
-        b = self.buildRead()
+        a = self.build_read()
+        b = self.build_read()
         self.assertEqual(hash(a), hash(b))
-        b.tid = 2
+        b.tid = 1
         self.assertNotEqual(hash(a), hash(b))
 
     def testUpdate(self):
         '''check if updating fields affects other variable length data
         '''
-        a = self.buildRead()
-        b = self.buildRead()
+        a = self.build_read()
+        b = self.build_read()
 
         # check qname
         b.query_name = "read_123"
@@ -116,19 +123,19 @@ class TestAlignedSegment(ReadTest):
         checkFieldEqual(self, a, b)
 
         # check seq
-        b.query_sequence = "ACGT"
+        b.query_sequence = "ATGC"
         checkFieldEqual(self,
                         a, b,
                         ("query_sequence", "query_qualities", "query_length"))
-        b.query_sequence = "ACGT" * 3
+        b.query_sequence = "ATGC" * 3
         checkFieldEqual(self,
                         a, b,
                         ("query_sequence", "query_qualities", "query_length"))
-        b.query_sequence = "ACGT" * 10
+        b.query_sequence = "ATGC" * 10
         checkFieldEqual(self, a, b, ("query_qualities",))
 
         # reset qual
-        b = self.buildRead()
+        b = self.build_read()
 
         # check flags:
         for x in (
@@ -151,25 +158,27 @@ class TestAlignedSegment(ReadTest):
         This does not work as setting the sequence will erase
         the quality scores.
         '''
-        a = self.buildRead()
+        a = self.build_read()
         a.query_sequence = a.query_sequence[5:10]
-        self.assertEqual(pysam.qualities_to_qualitystring(a.query_qualities), None)
+        self.assertEqual(pysam.qualities_to_qualitystring(
+            a.query_qualities), None)
 
-        a = self.buildRead()
+        a = self.build_read()
         s = pysam.qualities_to_qualitystring(a.query_qualities)
         a.query_sequence = a.query_sequence[5:10]
         a.query_qualities = pysam.qualitystring_to_array(s[5:10])
 
-        self.assertEqual(pysam.qualities_to_qualitystring(a.query_qualities), s[5:10])
+        self.assertEqual(pysam.qualities_to_qualitystring(
+            a.query_qualities), s[5:10])
 
     def testLargeRead(self):
         '''build an example read.'''
 
         a = pysam.AlignedSegment()
         a.query_name = "read_12345"
-        a.query_sequence = "ACGT" * 200
+        a.query_sequence = "ATGC" * 200
         a.flag = 0
-        a.reference_id = 0
+        a.reference_id = -1
         a.reference_start = 20
         a.mapping_quality = 20
         a.cigartuples = ((0, 4 * 200), )
@@ -182,14 +191,14 @@ class TestAlignedSegment(ReadTest):
 
     def testUpdateTlen(self):
         '''check if updating tlen works'''
-        a = self.buildRead()
+        a = self.build_read()
         oldlen = a.template_length
         oldlen *= 2
         a.template_length = oldlen
         self.assertEqual(a.template_length, oldlen)
 
     def testPositions(self):
-        a = self.buildRead()
+        a = self.build_read()
         self.assertEqual(a.get_reference_positions(),
                          [20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
                           31, 32, 33, 34, 35, 36, 37, 38, 39,
@@ -220,20 +229,20 @@ class TestAlignedSegment(ReadTest):
 
     def testFullReferencePositions(self):
         '''see issue 26'''
-        a = self.buildRead()
+        a = self.build_read()
         a.cigar = [(4, 30), (0, 20), (1, 3), (0, 47)]
 
         self.assertEqual(100,
                          len(a.get_reference_positions(full_length=True)))
 
     def testBlocks(self):
-        a = self.buildRead()
+        a = self.build_read()
         self.assertEqual(a.get_blocks(),
                          [(20, 30), (31, 40), (40, 60)])
 
     def test_infer_query_length(self):
         '''Test infer_query_length on M|=|X|I|D|H|S cigar ops'''
-        a = self.buildRead()
+        a = self.build_read()
         a.cigarstring = '40M'
         self.assertEqual(a.infer_query_length(), 40)
         a.cigarstring = '40='
@@ -252,10 +261,12 @@ class TestAlignedSegment(ReadTest):
         self.assertEqual(a.infer_query_length(), 35)
         a.cigarstring = '35M5S'
         self.assertEqual(a.infer_query_length(), 40)
+        a.cigarstring = None
+        self.assertEqual(a.infer_query_length(), None)
 
     def test_infer_read_length(self):
         '''Test infer_read_length on M|=|X|I|D|H|S cigar ops'''
-        a = self.buildRead()
+        a = self.build_read()
         a.cigarstring = '40M'
         self.assertEqual(a.infer_read_length(), 40)
         a.cigarstring = '40='
@@ -274,9 +285,11 @@ class TestAlignedSegment(ReadTest):
         self.assertEqual(a.infer_read_length(), 40)
         a.cigarstring = '35M5S'
         self.assertEqual(a.infer_read_length(), 40)
+        a.cigarstring = None
+        self.assertEqual(a.infer_read_length(), None)
 
     def test_get_aligned_pairs_soft_clipping(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.cigartuples = ((4, 2), (0, 35), (4, 3))
         self.assertEqual(a.get_aligned_pairs(),
                          [(0, None), (1, None)] +
@@ -292,7 +305,7 @@ class TestAlignedSegment(ReadTest):
                          )
 
     def test_get_aligned_pairs_hard_clipping(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.cigartuples = ((5, 2), (0, 35), (5, 3))
         self.assertEqual(a.get_aligned_pairs(),
                          # No seq, no seq pos
@@ -303,7 +316,7 @@ class TestAlignedSegment(ReadTest):
                              range(0, 0 + 35), range(20, 20 + 35))])
 
     def test_get_aligned_pairs_skip(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.cigarstring = "2M100D38M"
         self.assertEqual(a.get_aligned_pairs(),
                          [(0, 20), (1, 21)] +
@@ -319,7 +332,7 @@ class TestAlignedSegment(ReadTest):
                              range(20 + 2 + 100, 20 + 2 + 100 + 38))])
 
     def test_get_aligned_pairs_match_mismatch(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.cigartuples = ((7, 20), (8, 20))
         self.assertEqual(a.get_aligned_pairs(),
                          [(qpos, refpos) for (qpos, refpos) in zip(
@@ -329,7 +342,7 @@ class TestAlignedSegment(ReadTest):
                              range(0, 0 + 40), range(20, 20 + 40))])
 
     def test_get_aligned_pairs_padding(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.cigartuples = ((7, 20), (6, 1), (8, 19))
 
         def inner():
@@ -338,7 +351,7 @@ class TestAlignedSegment(ReadTest):
         self.assertRaises(NotImplementedError, inner)
 
     def test_get_aligned_pairs(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.query_sequence = "A" * 9
         a.cigarstring = "9M"
         a.set_tag("MD", "9")
@@ -363,7 +376,7 @@ class TestAlignedSegment(ReadTest):
              (3, 23, 'A'), (4, 24, 'c'),
              (None, 25, 'T'), (None, 26, 'T'),
              (5, 27, 'A'), (6, 28, 'A'), (7, 29, 'A'), (8, 30, 'A')]
-            )
+        )
 
         a.cigarstring = "5M2D2I2M"
         a.set_tag("MD", "4C^TT2")
@@ -374,10 +387,23 @@ class TestAlignedSegment(ReadTest):
              (None, 25, 'T'), (None, 26, 'T'),
              (5, None, None), (6, None, None),
              (7, 27, 'A'), (8, 28, 'A')]
-            )
+        )
+
+    def test_get_aligned_pairs_with_malformed_MD_tag(self):
+
+        a = self.build_read()
+        a.query_sequence = "A" * 9
+
+        # out of range issue, see issue #560
+        a.cigarstring = "64M2D85M2S"
+        a.set_tag("MD", "64^TG86A0")
+        self.assertRaises(
+            AssertionError,
+            a.get_aligned_pairs,
+            with_seq=True)
 
     def test_get_aligned_pairs_skip_reference(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.query_sequence = "A" * 10
         a.cigarstring = "5M1N5M"
         a.set_tag("MD", "10")
@@ -408,7 +434,7 @@ class TestAlignedSegment(ReadTest):
         '''issue 176: retrieving length without query sequence
         with soft-clipping.
         '''
-        a = self.buildRead()
+        a = self.build_read()
         a.query_sequence = None
         a.cigarstring = "20M"
         self.assertEqual(a.query_alignment_length, 20)
@@ -426,8 +452,7 @@ class TestAlignedSegment(ReadTest):
         self.assertEqual(a.query_alignment_length, 20)
 
     def test_query_length_is_limited(self):
-        
-        a = self.buildRead()
+        a = self.build_read()
         a.query_name = "A" * 1
         a.query_name = "A" * 251
         self.assertRaises(
@@ -437,12 +462,206 @@ class TestAlignedSegment(ReadTest):
             "query_name",
             "A" * 252)
 
+    def test_header_accessible(self):
+        a = self.build_read()
+        self.assertTrue(isinstance(a.header, pysam.AlignmentHeader))
+
+    def test_bin_values_for_unmapped_reads_ignore_length(self):
+        a = self.build_read()
+        # use a long read
+        a.cigarstring="2000000M"
+        self.assertEqual(a.bin, 9)
+        # changing unmapped flag changes bin because length is 0
+        a.is_unmapped = True
+        self.assertTrue(a.is_unmapped)
+        self.assertEqual(a.bin, 4681)
+        
+        # unmapped read without chromosomal location
+        a.reference_start = -1
+        self.assertEqual(a.reference_start, -1)
+        self.assertEqual(a.bin, 4680)
+
+    def test_bin_values_for_mapped_reads_are_updated(self):
+        a = self.build_read()
+        a.pos = 20000
+        self.assertFalse(a.is_unmapped)
+        self.assertEqual(a.bin, 4682)
+
+        # updating length updates bin
+        a.cigarstring="2000000M"
+        self.assertEqual(a.bin, 9)
+
+        # updating length updates bin
+        a.cigarstring="20M"
+        self.assertEqual(a.bin, 4682)
+
+        # updating length updates bin
+        a.reference_start = 2000000
+        self.assertEqual(a.bin, 4803)
+        
+
+class TestTidMapping(ReadTest):
+
+    def test_reference_name_can_be_set_to_none(self):
+        a = self.build_read()
+        a.reference_name = None
+        self.assertEqual(a.reference_name, None)
+        self.assertEqual(a.reference_id, -1)
+
+    def test_reference_name_can_be_set_to_asterisk(self):
+        a = self.build_read()
+        a.reference_name = "*"
+        self.assertEqual(a.reference_name, None)
+        self.assertEqual(a.reference_id, -1)
+
+    def test_reference_name_can_be_set_to_chromosome(self):
+        a = self.build_read()
+        a.reference_name = "chr1"
+        self.assertEqual(a.reference_name, "chr1")
+        self.assertEqual(a.reference_id, 0)
+
+    def test_reference_name_can_not_be_set_to_unknown_chromosome(self):
+        a = self.build_read()
+        self.assertRaises(ValueError,
+                          setattr,
+                          a,
+                          "reference_name",
+                          "chrX")
+        
+    def test_tid_can_be_set_to_missing(self):
+        a = self.build_read()
+        a.reference_id = -1
+        self.assertEqual(a.reference_id, -1)
+        self.assertEqual(a.reference_name, None)
+
+    def test_tid_can_be_set_to_missing_without_header(self):
+        a = pysam.AlignedSegment()
+        a.reference_id = -1
+        self.assertEqual(a.reference_id, -1)
+        self.assertEqual(a.reference_name, None)
+
+    def test_tid_can_be_set_without_header(self):
+        a = pysam.AlignedSegment()
+        a.reference_id = 1
+        self.assertRaises(ValueError, getattr, a, "reference_name")
+        
+    def test_tid_can_be_set_to_chromosome(self):
+        a = self.build_read()
+        a.reference_id = 0
+        self.assertEqual(a.reference_id, 0)
+        self.assertEqual(a.reference_name, "chr1")
+
+    def test_tid_can_not_be_set_to_unknown_chromosome(self):
+        a = self.build_read()
+        self.assertRaises(ValueError,
+                          setattr,
+                          a,
+                          "reference_id",
+                          2)
+        
+    def test_unmapped_tid_is_asterisk_in_output(self):
+        a = self.build_read()
+        a.reference_id = -1
+        self.assertEqual(a.to_string().split("\t")[2], "*")
+
+
+class TestNextTidMapping(ReadTest):
+
+    def test_next_reference_name_can_be_set_to_none(self):
+        a = self.build_read()
+        a.next_reference_name = None
+        self.assertEqual(a.next_reference_name, None)
+        self.assertEqual(a.next_reference_id, -1)
+
+    def test_next_reference_name_can_be_set_to_asterisk(self):
+        a = self.build_read()
+        a.next_reference_name = "*"
+        self.assertEqual(a.next_reference_name, None)
+        self.assertEqual(a.next_reference_id, -1)
+
+    def test_next_reference_name_can_be_set_to_chromosome(self):
+        a = self.build_read()
+        a.next_reference_name = "chr1"
+        self.assertEqual(a.next_reference_name, "chr1")
+        self.assertEqual(a.next_reference_id, 0)
+
+    def test_next_reference_name_can_not_be_set_to_unknown_chromosome(self):
+        a = self.build_read()
+        self.assertRaises(ValueError,
+                          setattr,
+                          a,
+                          "next_reference_name",
+                          "chrX")
+        
+    def test_next_tid_can_be_set_to_missing(self):
+        a = self.build_read()
+        a.next_reference_id = -1
+        self.assertEqual(a.next_reference_id, -1)
+        self.assertEqual(a.next_reference_name, None)
+
+    def test_next_tid_can_be_set_to_equal(self):
+        a = self.build_read()
+        a.reference_name = "chr1"
+        a.next_reference_name = "="
+        self.assertEqual(a.next_reference_id, a.reference_id)
+        self.assertEqual(a.next_reference_name, a.reference_name)
+        self.assertEqual(a.to_string().split("\t")[6], "=")
+        
+    def test_next_tid_can_be_set_to_missing_without_header(self):
+        a = pysam.AlignedSegment()
+        a.next_reference_id = -1
+        self.assertEqual(a.next_reference_id, -1)
+        self.assertEqual(a.next_reference_name, None)
+
+    def test_next_tid_can_be_set_without_header(self):
+        a = pysam.AlignedSegment()
+        a.next_reference_id = 1
+        self.assertRaises(ValueError, getattr, a, "next_reference_name")
+        
+    def test_next_tid_can_be_set_to_chromosome(self):
+        a = self.build_read()
+        a.next_reference_id = 0
+        self.assertEqual(a.next_reference_id, 0)
+        self.assertEqual(a.next_reference_name, "chr1")
+
+    def test_next_tid_can_not_be_set_to_unknown_chromosome(self):
+        a = self.build_read()
+        self.assertRaises(ValueError,
+                          setattr,
+                          a,
+                          "next_reference_id",
+                          2)
+        
+    def test_next_unmapped_tid_is_asterisk_in_output(self):
+        a = self.build_read()
+        a.next_reference_id = -1
+        self.assertEqual(a.to_string().split("\t")[6], "*")
+        
+        
+class TestCigar(ReadTest):
+
+    def testCigarString(self):
+        r = self.build_read()
+        self.assertEqual(r.cigarstring, "10M1D9M1I20M")
+        r.cigarstring = "20M10D20M"
+        self.assertEqual(r.cigartuples, [(0, 20), (2, 10), (0, 20)])
+        # unsetting cigar string
+        r.cigarstring = None
+        self.assertEqual(r.cigarstring, None)
+
+    def testCigar(self):
+        r = self.build_read()
+        self.assertEqual(
+            r.cigartuples, [(0, 10), (2, 1), (0, 9), (1, 1), (0, 20)])
+        # unsetting cigar string
+        r.cigartuples = None
+        self.assertEqual(r.cigartuples, None)
+
 
 class TestCigarStats(ReadTest):
-    
+
     def testStats(self):
-        
-        a = self.buildRead()
+        a = self.build_read()
 
         a.cigarstring = None
         self.assertEqual(
@@ -486,7 +705,7 @@ class TestCigarStats(ReadTest):
 
 
 class TestAlignedPairs(unittest.TestCase):
-    filename = os.path.join(DATADIR, "example_aligned_pairs.bam")
+    filename = os.path.join(BAM_DATADIR, "example_aligned_pairs.bam")
 
     def testReferenceBases(self):
         """reference bases should always be the same nucleotide
@@ -508,15 +727,15 @@ class TestAlignedPairs(unittest.TestCase):
 class TestTags(ReadTest):
 
     def testMissingTag(self):
-        a = self.buildRead()
+        a = self.build_read()
         self.assertRaises(KeyError, a.get_tag, "XP")
 
     def testEmptyTag(self):
-        a = self.buildRead()
+        a = self.build_read()
         self.assertRaises(KeyError, a.get_tag, "XT")
 
     def testSetTag(self):
-        a = self.buildRead()
+        a = self.build_read()
         self.assertEqual(False, a.has_tag("NM"))
         a.set_tag("NM", 2)
         self.assertEqual(True, a.has_tag("NM"))
@@ -530,7 +749,7 @@ class TestTags(ReadTest):
         a.set_tag("NM", None)
 
     def testArrayTags(self):
-        read = self.buildRead()
+        read = self.build_read()
         supported_dtypes = "bhBHf"
         unsupported_dtypes = "lLd"
 
@@ -545,9 +764,9 @@ class TestTags(ReadTest):
                               read.set_tag,
                               key,
                               array.array(dtype, range(10)))
-        
+
     def testAddTagsType(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.tags = None
         self.assertEqual(a.tags, [])
 
@@ -579,10 +798,10 @@ class TestTags(ReadTest):
                                  ('X5', 5)]))
 
         # test setting invalid type code
-        self.assertRaises(ValueError, a.setTag, 'X6', 5.2, 'g')
+        self.assertRaises(ValueError, a.set_tag, 'X6', 5.2, 'g')
 
     def testTagsUpdatingFloat(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.tags = [('NM', 1), ('RG', 'L1'),
                   ('PG', 'P1'), ('XT', 'U')]
 
@@ -595,7 +814,7 @@ class TestTags(ReadTest):
                           ('PG', 'P1'), ('XT', 'U'), ('XC', 5.0)])
 
     def testAddTags(self):
-        a = self.buildRead()
+        a = self.build_read()
         a.tags = [('NM', 1), ('RG', 'L1'),
                   ('PG', 'P1'), ('XT', 'U')]
 
@@ -633,7 +852,7 @@ class TestTags(ReadTest):
         see http://groups.google.com/group/pysam-user-group/browse_thread/thread/67ca204059ea465a
         '''
         samfile = pysam.AlignmentFile(
-            os.path.join(DATADIR, "ex8.bam"),
+            os.path.join(BAM_DATADIR, "ex8.bam"),
             "rb")
 
         for entry in samfile:
@@ -643,7 +862,7 @@ class TestTags(ReadTest):
             self.assertEqual(after, before)
 
     def testMDTagMatchOnly(self):
-        a = self.buildRead()
+        a = self.build_read()
 
         # Substitutions only
         a.cigarstring = "21M"
@@ -668,7 +887,7 @@ class TestTags(ReadTest):
             a.get_reference_sequence())
 
     def testMDTagInsertions(self):
-        a = self.buildRead()
+        a = self.build_read()
 
         # insertions are silent in the reference sequence
         a.cigarstring = "5M1I5M"
@@ -691,7 +910,7 @@ class TestTags(ReadTest):
             "A" * 10)
 
     def testMDTagDeletions(self):
-        a = self.buildRead()
+        a = self.build_read()
 
         a.cigarstring = "5M1D5M"
         a.query_sequence = "A" * 10
@@ -708,7 +927,7 @@ class TestTags(ReadTest):
             a.get_reference_sequence())
 
     def testMDTagRefSkipping(self):
-        a = self.buildRead()
+        a = self.build_read()
 
         a.cigarstring = "5M1N5M"
         a.query_sequence = "A" * 10
@@ -725,7 +944,7 @@ class TestTags(ReadTest):
             a.get_reference_sequence())
 
     def testMDTagSoftClipping(self):
-        a = self.buildRead()
+        a = self.build_read()
 
         # softclipping
         a.cigarstring = "5S5M1D5M5S"
@@ -744,7 +963,7 @@ class TestTags(ReadTest):
             a.get_reference_sequence())
 
     def testMDTagComplex(self):
-        a = self.buildRead()
+        a = self.build_read()
 
         a.cigarstring = "5S5M1I2D5M5S"
         a.query_sequence = "G" * 5 + "A" * 11 + "G" * 5
@@ -777,11 +996,79 @@ class TestTags(ReadTest):
             "AAAAcTTAA",
             a.get_reference_sequence())
 
+    def testArrayTags(self):
+
+        r = self.build_read()
+
+        def c(r, l):
+            r.tags = [('ZM', l)]
+            self.assertEqual(list(r.opt("ZM")), list(l))
+
+        # signed integers
+        c(r, (-1, 1))
+        c(r, (-1, 100))
+        c(r, (-1, 200))
+        c(r, (-1, 1000))
+        c(r, (-1, 30000))
+        c(r, (-1, 50000))
+        c(r, (1, -1))
+        c(r, (1, -100))
+        c(r, (1, -200))
+        c(r, (1, -1000))
+        c(r, (1, -30000))
+        c(r, (1, -50000))
+
+        # unsigned integers
+        c(r, (1, 100))
+        c(r, (1, 1000))
+        c(r, (1, 10000))
+        c(r, (1, 100000))
+
+        # floats
+        c(r, (1.0, 100.0))
+
+    def testLongTags(self):
+        '''see issue 115'''
+
+        r = self.build_read()
+        rg = 'HS2000-899_199.L3'
+        tags = [('XC', 85), ('XT', 'M'), ('NM', 5),
+                ('SM', 29), ('AM', 29), ('XM', 1),
+                ('XO', 1), ('XG', 4), ('MD', '37^ACCC29T18'),
+                ('XA', '5,+11707,36M1I48M,2;21,-48119779,46M1I38M,2;hs37d5,-10060835,40M1D45M,3;5,+11508,36M1I48M,3;hs37d5,+6743812,36M1I48M,3;19,-59118894,46M1I38M,3;4,-191044002,6M1I78M,3;')]  # noqa
+
+        r.tags = tags
+        r.tags += [("RG", rg)] * 100
+        tags += [("RG", rg)] * 100
+
+        self.assertEqual(tags, r.tags)
+
+    def testNegativeIntegers(self):
+        x = -2
+        aligned_read = self.build_read()
+        aligned_read.tags = [("XD", int(x))]
+        self.assertEqual(aligned_read.opt('XD'), x)
+        # print (aligned_read.tags)
+
+    def testNegativeIntegersWrittenToFile(self):
+        r = self.build_read()
+        x = -2
+        r.tags = [("XD", x)]
+        with get_temp_context("negative_integers.bam") as fn:
+            with pysam.AlignmentFile(fn,
+                                     "wb",
+                                     referencenames=("chr1",),
+                                     referencelengths=(1000,)) as outf:
+                outf.write(r)
+            with pysam.AlignmentFile(fn) as inf:
+                r = next(inf)
+            self.assertEqual(r.tags, [("XD", x)])
+
 
 class TestCopy(ReadTest):
 
     def testCopy(self):
-        a = self.buildRead()
+        a = self.build_read()
         b = copy.copy(a)
         # check if a and be are the same
         self.assertEqual(a, b)
@@ -793,7 +1080,7 @@ class TestCopy(ReadTest):
         self.assertEqual(b.query_name, 'ReadB')
 
     def testDeepCopy(self):
-        a = self.buildRead()
+        a = self.build_read()
         b = copy.deepcopy(a)
         # check if a and be are the same
         self.assertEqual(a, b)
@@ -805,20 +1092,99 @@ class TestCopy(ReadTest):
         self.assertEqual(b.query_name, 'ReadB')
 
 
-class TestAsString(unittest.TestCase):
+class TestSetTagGetTag(ReadTest):
 
-    def testAsString(self):
-        with open(os.path.join(DATADIR, "ex2.sam")) as samf:
-            reference = [x[:-1] for x in samf if not x.startswith("@")]
+    def check_tag(self, tag, value, value_type, alt_value_type=None):
+        a = self.build_read()
+        a.set_tag(tag, value, value_type=value_type)
+        v, t = a.get_tag(tag, with_value_type=True)
+        self.assertEqual(v, value)
 
-        with pysam.AlignmentFile(
-            os.path.join(DATADIR, "ex2.bam"), "r") as pysamf:
-            for s, p in zip(reference, pysamf):
-                self.assertEqual(s, p.tostring(pysamf))
+        if alt_value_type:
+            self.assertEqual(t, alt_value_type)
+        else:
+            self.assertEqual(t, value_type)
+
+    def test_set_tag_with_A(self):
+        self.check_tag('TT', "x", value_type="A")
+
+    def test_set_tag_with_a(self):
+        self.check_tag('TT', "x", value_type="a", alt_value_type="A")
+
+    def test_set_tag_with_C(self):
+        self.check_tag('TT', 12, value_type="C")
+
+    def test_set_tag_with_c(self):
+        self.check_tag('TT', 12, value_type="c")
+
+    def test_set_tag_with_S(self):
+        self.check_tag('TT', 12, value_type="S")
+
+    def test_set_tag_with_s(self):
+        self.check_tag('TT', 12, value_type="s")
+
+    def test_set_tag_with_I(self):
+        self.check_tag('TT', 12, value_type="I")
+
+    def test_set_tag_with_i(self):
+        self.check_tag('TT', 12, value_type="i")
+
+    def test_set_tag_with_f(self):
+        self.check_tag('TT', 2.5, value_type="f")
+
+    def test_set_tag_with_d(self):
+        self.check_tag('TT', 2.5, value_type="d")
+
+    def test_set_tag_with_H(self):
+        self.check_tag('TT', "AE12", value_type="H")
+
+    def test_set_tag_with_automated_type_detection(self):
+        self.check_tag('TT', -(1 << 7), value_type=None, alt_value_type="c")
+        self.check_tag('TT', -(1 << 7) - 1,
+                       value_type=None, alt_value_type="s")
+        self.check_tag('TT', -(1 << 15), value_type=None, alt_value_type="s")
+        self.check_tag('TT', -(1 << 15) - 1,
+                       value_type=None, alt_value_type="i")
+        self.check_tag('TT', -(1 << 31), value_type=None, alt_value_type="i")
+        self.assertRaises(
+            ValueError,
+            self.check_tag,
+            'TT',
+            -(1 << 31) - 1,
+            value_type=None,
+            alt_value_type="i")
+
+        self.check_tag('TT', (1 << 8) - 1, value_type=None, alt_value_type="C")
+        self.check_tag('TT', (1 << 8), value_type=None, alt_value_type="S")
+        self.check_tag('TT', (1 << 16) - 1,
+                       value_type=None, alt_value_type="S")
+        self.check_tag('TT', (1 << 16), value_type=None, alt_value_type="I")
+        self.check_tag('TT', (1 << 32) - 1,
+                       value_type=None, alt_value_type="I")
+        self.assertRaises(
+            ValueError,
+            self.check_tag,
+            'TT',
+            (1 << 32),
+            value_type=None,
+            alt_value_type="I")
+
+
+class TestSetTagsGetTag(TestSetTagGetTag):
+
+    def check_tag(self, tag, value, value_type, alt_value_type=None):
+        a = self.build_read()
+        a.set_tags([(tag, value, value_type)])
+        v, t = a.get_tag(tag, with_value_type=True)
+        if alt_value_type:
+            self.assertEqual(t, alt_value_type)
+        else:
+            self.assertEqual(t, value_type)
+        self.assertEqual(v, value)
 
 
 class TestEnums(unittest.TestCase):
-    
+
     def test_cigar_enums_are_defined(self):
         self.assertEqual(pysam.CMATCH, 0)
         self.assertEqual(pysam.CINS, 1)
@@ -846,5 +1212,137 @@ class TestEnums(unittest.TestCase):
         self.assertEqual(pysam.FSUPPLEMENTARY, 2048)
 
 
+class TestBuildingReadsWithoutHeader(unittest.TestCase):
+    
+    def build_read(self):
+        '''build an example read, but without header information.'''
+
+        a = pysam.AlignedSegment()
+        a.query_name = "read_12345"
+        a.query_sequence = "ATGC" * 10
+        a.flag = 0
+        a.reference_id = -1
+        a.reference_start = 20
+        a.mapping_quality = 20
+        a.cigartuples = ((0, 10), (2, 1), (0, 9), (1, 1), (0, 20))
+        a.next_reference_id = 0
+        a.next_reference_start = 200
+        a.template_length = 167
+        a.query_qualities = pysam.qualitystring_to_array("1234") * 10
+        # todo: create tags
+        return a
+
+    def test_read_can_be_constructed_without_header(self):
+        read = self.build_read()
+        self.assertEqual(read.query_name, "read_12345")
+            
+    def test_reference_id_can_be_set(self):
+        read = self.build_read()
+        read.reference_id = 2
+        self.assertEqual(read.reference_id, 2)
+
+    def test_reference_name_is_not_available(self):
+        read = self.build_read()
+        self.assertRaises(
+            ValueError,
+            setattr,
+            read,
+            "reference_name",
+            "chr2")
+        
+    def test_read_can_be_written_to_file(self):
+        tmpfilename = get_temp_filename(".bam")
+        with pysam.AlignmentFile(tmpfilename, "wb",
+                                 reference_names=["chr1", "chr2", "chr3"],
+                                 reference_lengths=[1000, 2000, 3000]) as outf:
+            read = self.build_read()
+            read.reference_id = 2
+            outf.write(read)
+
+        stdout = pysam.samtools.view(tmpfilename)
+        chromosome = stdout.split("\t")[2]
+        self.assertEqual(chromosome, "chr3")
+        os.unlink(tmpfilename)
+
+
+class TestForwardStrandValues(ReadTest):
+
+    def test_sequence_is_complemented(self):
+        a = self.build_read()
+        a.is_reverse = False
+        fwd_seq = a.query_sequence
+        
+        rev_seq = fwd_seq.translate(maketrans("ACGTacgtNnXx", "TGCAtgcaNnXx"))[::-1]
+        self.assertEqual(fwd_seq, a.get_forward_sequence())
+        a.is_reverse = True        
+        self.assertEqual(fwd_seq, a.query_sequence)
+        self.assertEqual(rev_seq, a.get_forward_sequence())
+
+    def test_qualities_are_complemented(self):
+        a = self.build_read()
+        a.is_reverse = False
+        fwd_qual = a.query_qualities
+        rev_qual = fwd_qual[::-1]
+        self.assertEqual(fwd_qual, a.get_forward_qualities())
+        a.is_reverse = True        
+        self.assertEqual(fwd_qual, a.query_qualities)
+        self.assertEqual(rev_qual, a.get_forward_qualities())
+
+
+class TestExportImport(ReadTest):
+
+    def test_string_export(self):
+        a = self.build_read()
+        self.assertEqual(a.to_string(),
+                         "read_12345\t0\tchr1\t21\t20\t10M1D9M1I20M\t=\t201\t167\t"
+                         "ATGCATGCATGCATGCATGCATGCATGCATGCATGCATGC\t1234123412341234123412341234123412341234")
+
+    def test_string_export_import_without_tags(self):
+        a = self.build_read()
+        a.tags = []
+        b = pysam.AlignedSegment.fromstring(a.to_string(), a.header)
+        self.assertEqual(a, b)
+
+    def test_string_export_import_with_tags(self):
+        a = self.build_read()
+        a.tags = [("XD", 12), ("RF", "abc")]
+        b = pysam.AlignedSegment.fromstring(a.to_string(), a.header)
+        self.assertEqual(a, b)
+        
+    def test_to_string_without_alignment_file(self):
+        with open(os.path.join(BAM_DATADIR, "ex2.sam")) as samf:
+            reference = [x[:-1] for x in samf if not x.startswith("@")]
+
+        with pysam.AlignmentFile(
+            os.path.join(BAM_DATADIR, "ex2.bam"), "r") as pysamf:
+            for s, p in zip(reference, pysamf):
+                self.assertEqual(s, p.to_string())
+                
+    def test_dict_export(self):
+        a = self.build_read()
+        a.tags = [("XD", 12), ("RF", "abc")]
+        
+        self.assertEqual(
+            a.to_dict(),
+            json.loads(
+                '{"name": "read_12345", "flag": "0", "ref_name": "chr1", "ref_pos": "21", '
+                '"map_quality": "20", "cigar": "10M1D9M1I20M", "next_ref_name": "=", '
+                '"next_ref_pos": "201", "length": "167", '
+                '"seq": "ATGCATGCATGCATGCATGCATGCATGCATGCATGCATGC", '
+                '"qual": "1234123412341234123412341234123412341234", "tags": ["XD:i:12", "RF:Z:abc"]}'))
+
+    def test_string_export_import_without_tags(self):
+        a = self.build_read()
+        a.tags = []
+        b = pysam.AlignedSegment.from_dict(a.to_dict(), a.header)
+        self.assertEqual(a, b)
+
+    def test_string_export_import_with_tags(self):
+        a = self.build_read()
+        a.tags = [("XD", 12), ("RF", "abc")]
+        b = pysam.AlignedSegment.from_dict(a.to_dict(), a.header)
+        self.assertEqual(a, b)
+                
+        
 if __name__ == "__main__":
     unittest.main()
