@@ -2,6 +2,7 @@ import os
 import sys
 import unittest
 import pysam
+import shutil
 import gzip
 import subprocess
 
@@ -10,9 +11,7 @@ try:
 except ImportError:
     Path = None
 
-from TestUtils import get_temp_filename, check_lines_equal, load_and_convert
-
-DATADIR="cbcf_data"
+from TestUtils import get_temp_filename, check_lines_equal, load_and_convert, CBCF_DATADIR, get_temp_context
 
 
 def read_header(filename):
@@ -37,21 +36,21 @@ class TestMissingGenotypes(unittest.TestCase):
 
     def setUp(self):
         self.compare = load_and_convert(
-            os.path.join(DATADIR, self.filename),
+            os.path.join(CBCF_DATADIR, self.filename),
             encode=False)
 
     def check(self, filename):
         """see issue 203 - check for segmentation fault"""
-        fn = os.path.join(DATADIR, filename)
+        fn = os.path.join(CBCF_DATADIR, filename)
         self.assertEqual(True, os.path.exists(fn))
         v = pysam.VariantFile(fn)
         for site in v:
-            for ss,rec in site.samples.items():
+            for ss, rec in site.samples.items():
                 a, b = ss, rec
 
         v = pysam.VariantFile(fn)
         for x, site in enumerate(v):
-            for ss,rec in site.samples.items():
+            for ss, rec in site.samples.items():
                 a, b = ss, rec.alleles
                 a, b = ss, rec.allele_indices
 
@@ -62,6 +61,41 @@ class TestMissingGenotypes(unittest.TestCase):
         self.check(self.filename + ".gz")
 
 
+class TestMissingSamples(unittest.TestCase):
+
+    filename = "gnomad.vcf"
+
+    def setUp(self):
+        self.compare = load_and_convert(
+            os.path.join(CBCF_DATADIR, self.filename),
+            encode=False)
+
+    def check(self, filename):
+        """see issue #593"""
+        fn = os.path.join(CBCF_DATADIR, filename)
+        self.assertEqual(True, os.path.exists(fn))
+        expect_fail = not "fixed" in self.filename
+        with pysam.VariantFile(fn) as inf:
+            rec = next(inf.fetch())
+            if expect_fail:
+                self.assertRaises(ValueError, rec.info.__getitem__, "GC")
+            else:
+                self.assertEqual(rec.info["GC"], (27, 35, 16))
+
+    def testVCF(self):
+        self.check(self.filename)
+
+    def testVCFGZ(self):
+        self.check(self.filename + ".gz")
+
+
+class TestMissingSamplesFixed(TestMissingSamples):
+    # workaround for NUMBER=G in INFO records:
+    # perl 's/Number=G/Number=./ if (/INFO/)'
+    
+    filename = "gnomad_fixed.vcf"
+
+
 class TestOpening(unittest.TestCase):
 
     def testMissingFile(self):
@@ -73,68 +107,56 @@ class TestOpening(unittest.TestCase):
                           "missing_file.vcf.gz")
 
     def testEmptyFileVCF(self):
-        with open("tmp_testEmptyFile.vcf", "w"):
-            pass
-
-        self.assertRaises(ValueError, pysam.VariantFile,
-                          "tmp_testEmptyFile.vcf")
-
-        os.unlink("tmp_testEmptyFile.vcf")
-
-
-    if Path and sys.version_info >= (3,6):
-        def testEmptyFileVCFFromPath(self):
-            with open("tmp_testEmptyFile.vcf", "w"):
+        with get_temp_context("tmp_testEmptyFile.vcf") as fn:
+            with open(fn, "w"):
                 pass
+            self.assertRaises(ValueError, pysam.VariantFile, fn)
 
-            self.assertRaises(ValueError, pysam.VariantFile,
-                              Path("tmp_testEmptyFile.vcf"))
-
-            os.unlink("tmp_testEmptyFile.vcf")
+    if Path and sys.version_info >= (3, 6):
+        def testEmptyFileVCFFromPath(self):
+            with get_temp_context("tmp_testEmptyFile.vcf") as fn:
+                with open(fn, "w"):
+                    pass
+                self.assertRaises(ValueError, pysam.VariantFile,
+                                  Path(fn))
 
     def testEmptyFileVCFGZWithIndex(self):
-        with open("tmp_testEmptyFile.vcf", "w"):
-            pass
+        with get_temp_context("tmp_testEmptyFile.vcf") as fn:
+            with open(fn, "w"):
+                pass
+            # tabix_index will automatically compress
+            pysam.tabix_index(fn,
+                              preset="vcf",
+                              force=True)
 
-        pysam.tabix_index("tmp_testEmptyFile.vcf",
-                          preset="vcf",
-                          force=True)
-
-        self.assertRaises(ValueError, pysam.VariantFile,
-                          "tmp_testEmptyFile.vcf.gz")
-
-        os.unlink("tmp_testEmptyFile.vcf.gz")
-        os.unlink("tmp_testEmptyFile.vcf.gz.tbi")
+            self.assertRaises(ValueError, pysam.VariantFile, fn + ".gz")
 
     def testEmptyFileVCFGZWithoutIndex(self):
-        with open("tmp_testEmptyFileWithoutIndex.vcf", "w"):
-            pass
+        with get_temp_context("tmp_testEmptyFileWithoutIndex.vcf") as fn:
+            with open(fn, "w"):
+                pass
 
-        pysam.tabix_compress("tmp_testEmptyFileWithoutIndex.vcf",
-                             "tmp_testEmptyFileWithoutIndex.vcf.gz",
-                             force=True)
+            pysam.tabix_compress(fn,
+                                 fn + ".gz",
+                                 force=True)
 
-        self.assertRaises(ValueError, pysam.VariantFile,
-                          "tmp_testEmptyFileWithoutIndex.vcf.gz")
-
-        os.unlink("tmp_testEmptyFileWithoutIndex.vcf")
-        os.unlink("tmp_testEmptyFileWithoutIndex.vcf.gz")
+            self.assertRaises(ValueError, pysam.VariantFile, fn + ".gz")
 
     def testEmptyFileVCFOnlyHeader(self):
         with pysam.VariantFile(os.path.join(
-                DATADIR,
+                CBCF_DATADIR,
                 "example_vcf42_only_header.vcf")) as inf:
             self.assertEqual(len(list(inf.fetch())), 0)
 
     def testEmptyFileVCFGZOnlyHeader(self):
         with pysam.VariantFile(os.path.join(
-                DATADIR,
+                CBCF_DATADIR,
                 "example_vcf42_only_header.vcf")) as inf:
             self.assertEqual(len(list(inf.fetch())), 0)
 
     def testDetectVCF(self):
-        with pysam.VariantFile(os.path.join(DATADIR,
-            "example_vcf40.vcf")) as inf:
+        with pysam.VariantFile(os.path.join(CBCF_DATADIR,
+                                            "example_vcf40.vcf")) as inf:
             self.assertEqual(inf.category, 'VARIANTS')
             self.assertEqual(inf.format, 'VCF')
             self.assertEqual(inf.compression, 'NONE')
@@ -143,8 +165,8 @@ class TestOpening(unittest.TestCase):
             self.assertEqual(len(list(inf.fetch())), 5)
 
     def testDetectVCFGZ(self):
-        with pysam.VariantFile(os.path.join(DATADIR,
-            "example_vcf40.vcf.gz")) as inf:
+        with pysam.VariantFile(os.path.join(CBCF_DATADIR,
+                                            "example_vcf40.vcf.gz")) as inf:
             self.assertEqual(inf.category, 'VARIANTS')
             self.assertEqual(inf.format, 'VCF')
             self.assertEqual(inf.compression, 'BGZF')
@@ -154,7 +176,7 @@ class TestOpening(unittest.TestCase):
 
     def testDetectBCF(self):
         with pysam.VariantFile(os.path.join(
-                DATADIR,
+                CBCF_DATADIR,
                 "example_vcf40.bcf")) as inf:
             self.assertEqual(inf.category, 'VARIANTS')
             self.assertEqual(inf.format, 'BCF')
@@ -164,13 +186,74 @@ class TestOpening(unittest.TestCase):
             self.assertEqual(len(list(inf.fetch())), 5)
 
 
+class TestIndexFormatsVCF(unittest.TestCase):
+
+    vcf_filename = os.path.join(CBCF_DATADIR, "example_vcf40.vcf")
+    bcf_filename = os.path.join(CBCF_DATADIR, "example_vcf40.bcf")
+    
+    def test_vcf_with_tbi_index(self):
+        with get_temp_context("tmp_fn.vcf") as fn:
+            shutil.copyfile(self.vcf_filename, fn)
+            pysam.tabix_index(fn, preset="vcf", force=True)
+            self.assertTrue(os.path.exists(fn + ".gz" + ".tbi"))
+            self.assertFalse(os.path.exists(fn + ".gz" + ".csi"))
+            
+            with pysam.VariantFile(fn + ".gz") as inf:
+                self.assertEqual(len(list(inf.fetch("20"))), 3)
+
+    def test_vcf_with_csi_index(self):
+        with get_temp_context("tmp_fn.vcf") as fn:
+            shutil.copyfile(self.vcf_filename, fn)
+
+            pysam.tabix_index(fn, preset="vcf", force=True, csi=True)
+            self.assertTrue(os.path.exists(fn + ".gz" + ".csi"))
+            self.assertFalse(os.path.exists(fn + ".gz" + ".tbi"))
+            
+            with pysam.VariantFile(fn + ".gz") as inf:
+                self.assertEqual(len(list(inf.fetch("20"))), 3)
+
+    def test_bcf_with_prebuilt_csi(self):
+        with get_temp_context("tmp_fn.bcf") as fn:
+            shutil.copyfile(self.bcf_filename, fn)
+            shutil.copyfile(self.bcf_filename + ".csi", fn + ".csi")
+
+            self.assertTrue(os.path.exists(fn + ".csi"))
+            self.assertFalse(os.path.exists(fn + ".tbi"))
+            
+            with pysam.VariantFile(fn) as inf:
+                self.assertEqual(len(list(inf.fetch("20"))), 3)
+
+    def test_bcf_with_tbi_index_will_produce_csi(self):
+        with get_temp_context("tmp_fn.bcf") as fn:
+            shutil.copyfile(self.bcf_filename, fn)
+
+            pysam.tabix_index(fn, preset="bcf", force=True, csi=False)
+            self.assertTrue(os.path.exists(fn + ".csi"))
+            self.assertFalse(os.path.exists(fn + ".tbi"))
+            
+            with pysam.VariantFile(fn) as inf:
+                self.assertEqual(len(list(inf.fetch("20"))), 3)
+
+    def test_bcf_with_csi_index(self):
+        with get_temp_context("tmp_fn.bcf") as fn:
+            shutil.copyfile(self.bcf_filename, fn)
+
+            pysam.tabix_index(fn, preset="vcf", force=True, csi=True)
+            
+            self.assertTrue(os.path.exists(fn + ".csi"))
+            self.assertFalse(os.path.exists(fn + ".tbi"))
+            
+            with pysam.VariantFile(fn) as inf:
+                self.assertEqual(len(list(inf.fetch("20"))), 3)
+
+
 class TestHeader(unittest.TestCase):
 
     filename = "example_vcf40.vcf"
 
     def testStr(self):
 
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
 
         ref = read_header(fn)
@@ -181,7 +264,7 @@ class TestHeader(unittest.TestCase):
 
     def testIterator(self):
 
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
 
         ref = read_header(fn)
@@ -207,85 +290,91 @@ class TestParsing(unittest.TestCase):
     filename = "example_vcf40.vcf.gz"
 
     def testChrom(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         chrom = [rec.chrom for rec in v]
         self.assertEqual(chrom, ['M', '17', '20', '20', '20'])
 
-    if Path and sys.version_info >= (3,6):
+    if Path and sys.version_info >= (3, 6):
         def testChromFromPath(self):
-            fn = os.path.join(DATADIR, self.filename)
+            fn = os.path.join(CBCF_DATADIR, self.filename)
             v = pysam.VariantFile(Path(fn))
             chrom = [rec.chrom for rec in v]
             self.assertEqual(chrom, ['M', '17', '20', '20', '20'])
 
     def testPos(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         pos = [rec.pos for rec in v]
         self.assertEqual(pos, [1230237, 14370, 17330, 1110696, 1234567])
 
     def testStart(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         start = [rec.start for rec in v]
         self.assertEqual(start, [1230236, 14369, 17329, 1110695, 1234566])
 
     def testStop(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         stop = [rec.stop for rec in v]
         self.assertEqual(stop, [1230237, 14370, 17330, 1110696, 1234570])
 
     def testId(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         ids = [rec.id for rec in v]
-        self.assertEqual(ids, [None, 'rs6054257', None, 'rs6040355', 'microsat1'])
+        self.assertEqual(
+            ids, [None, 'rs6054257', None, 'rs6040355', 'microsat1'])
 
     def testRef(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         ref = [rec.ref for rec in v]
         self.assertEqual(ref, ['T', 'G', 'T', 'A', 'GTCT'])
 
     def testAlt(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         alts = [rec.alts for rec in v]
-        self.assertEqual(alts, [None, ('A',), ('A',), ('G', 'T'), ('G', 'GTACT')])
+        self.assertEqual(alts, [None, ('A',), ('A',),
+                                ('G', 'T'), ('G', 'GTACT')])
 
     def testAlleles(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         alleles = [rec.alleles for rec in v]
-        self.assertEqual(alleles, [('T',), ('G', 'A'), ('T', 'A'), ('A', 'G', 'T'), ('GTCT', 'G', 'GTACT')])
+        self.assertEqual(alleles, [
+                         ('T',), ('G', 'A'), ('T', 'A'), ('A', 'G', 'T'), ('GTCT', 'G', 'GTACT')])
 
     def testQual(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         qual = [rec.qual for rec in v]
         self.assertEqual(qual, [47.0, 29.0, 3.0, 67.0, 50.0])
 
     def testFilter(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         filter = [rec.filter.keys() for rec in v]
-        self.assertEqual(filter, [['PASS'], ['PASS'], ['q10'], ['PASS'], ['PASS']])
+        self.assertEqual(filter, [['PASS'], ['PASS'],
+                                  ['q10'], ['PASS'], ['PASS']])
 
     def testInfo(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         info = [rec.info.items() for rec in v]
         self.assertEqual(info, [[('NS', 3), ('DP', 13), ('AA', 'T')],
-                                [('NS', 3), ('DP', 14), ('AF', (0.5,)), ('DB', True), ('H2', True)],
-                                [('NS', 3), ('DP', 11), ('AF', (0.017000000923871994,))],
+                                [('NS', 3), ('DP', 14), ('AF', (0.5,)),
+                                 ('DB', True), ('H2', True)],
+                                [('NS', 3), ('DP', 11),
+                                 ('AF', (0.017000000923871994,))],
                                 [('NS', 2), ('DP', 10), ('AF', (0.3330000042915344, 0.6669999957084656)),
-                                            ('AA', 'T'), ('DB', True)],
+                                 ('AA', 'T'), ('DB', True)],
                                 [('NS', 3), ('DP', 9), ('AA', 'G')]])
 
     def testFormat(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         format = [rec.format.keys() for rec in v]
         self.assertEqual(format, [['GT', 'GQ', 'DP', 'HQ'],
@@ -295,7 +384,7 @@ class TestParsing(unittest.TestCase):
                                   ['GT', 'GQ', 'DP']])
 
     def testSampleAlleles(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         alleles = [s.alleles for rec in v for s in rec.samples.values()]
         self.assertEqual(alleles, [('T', 'T'), ('T', 'T'), ('T', 'T'),
@@ -306,27 +395,38 @@ class TestParsing(unittest.TestCase):
                                    ('G', 'G')])
 
     def testSampleFormats(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         format = [s.items() for rec in v for s in rec.samples.values()]
         self.assertEqual(format, [[('GT', (0, 0)), ('GQ', 54), ('DP', 7), ('HQ', (56, 60))],
-                                  [('GT', (0, 0)), ('GQ', 48), ('DP', 4), ('HQ', (51, 51))],
-                                  [('GT', (0, 0)), ('GQ', 61), ('DP', 2), ('HQ', (None,))],
-                                  [('GT', (0, 0)), ('GQ', 48), ('DP', 1), ('HQ', (51, 51))],
-                                  [('GT', (1, 0)), ('GQ', 48), ('DP', 8), ('HQ', (51, 51))],
-                                  [('GT', (1, 1)), ('GQ', 43), ('DP', 5), ('HQ', (None, None))],
-                                  [('GT', (0, 0)), ('GQ', 49), ('DP', 3), ('HQ', (58, 50))],
-                                  [('GT', (0, 1)), ('GQ', 3), ('DP', 5), ('HQ', (65, 3))],
-                                  [('GT', (0, 0)), ('GQ', 41), ('DP', 3), ('HQ', (None,))],
-                                  [('GT', (1, 2)), ('GQ', 21), ('DP', 6), ('HQ', (23, 27))],
-                                  [('GT', (2, 1)), ('GQ', 2), ('DP', 0), ('HQ', (18, 2))],
-                                  [('GT', (2, 2)), ('GQ', 35), ('DP', 4), ('HQ', (None,))],
+                                  [('GT', (0, 0)), ('GQ', 48),
+                                   ('DP', 4), ('HQ', (51, 51))],
+                                  [('GT', (0, 0)), ('GQ', 61),
+                                   ('DP', 2), ('HQ', (None,))],
+                                  [('GT', (0, 0)), ('GQ', 48),
+                                   ('DP', 1), ('HQ', (51, 51))],
+                                  [('GT', (1, 0)), ('GQ', 48),
+                                   ('DP', 8), ('HQ', (51, 51))],
+                                  [('GT', (1, 1)), ('GQ', 43),
+                                   ('DP', 5), ('HQ', (None, None))],
+                                  [('GT', (0, 0)), ('GQ', 49),
+                                   ('DP', 3), ('HQ', (58, 50))],
+                                  [('GT', (0, 1)), ('GQ', 3),
+                                   ('DP', 5), ('HQ', (65, 3))],
+                                  [('GT', (0, 0)), ('GQ', 41),
+                                   ('DP', 3), ('HQ', (None,))],
+                                  [('GT', (1, 2)), ('GQ', 21),
+                                   ('DP', 6), ('HQ', (23, 27))],
+                                  [('GT', (2, 1)), ('GQ', 2),
+                                   ('DP', 0), ('HQ', (18, 2))],
+                                  [('GT', (2, 2)), ('GQ', 35),
+                                   ('DP', 4), ('HQ', (None,))],
                                   [('GT', (0, 1)), ('GQ', 35), ('DP', 4)],
                                   [('GT', (0, 2)), ('GQ', 17), ('DP', 2)],
                                   [('GT', (1, 1)), ('GQ', 40), ('DP', 3)]])
 
     def testSampleAlleleIndices(self):
-        fn = os.path.join(DATADIR, self.filename)
+        fn = os.path.join(CBCF_DATADIR, self.filename)
         v = pysam.VariantFile(fn)
         indices = [s.allele_indices for rec in v for s in rec.samples.values()]
         self.assertEqual(indices, [(0, 0), (0, 0), (0, 0), (0, 0), (1, 0),
@@ -338,16 +438,15 @@ class TestIndexFilename(unittest.TestCase):
 
     filenames = [('example_vcf40.vcf.gz', 'example_vcf40.vcf.gz.tbi'),
                  ('example_vcf40.vcf.gz', 'example_vcf40.vcf.gz.csi'),
-                 ('example_vcf40.bcf',    'example_vcf40.bcf.csi')]
+                 ('example_vcf40.bcf', 'example_vcf40.bcf.csi')]
 
     def testOpen(self):
         for fn, idx_fn in self.filenames:
-            fn = os.path.join(DATADIR, fn)
-            idx_fn = os.path.join(DATADIR, idx_fn)
+            fn = os.path.join(CBCF_DATADIR, fn)
+            idx_fn = os.path.join(CBCF_DATADIR, idx_fn)
 
-            v = pysam.VariantFile(fn, index_filename=idx_fn)
-
-            self.assertEqual(len(list(v.fetch('20'))), 3)
+            with pysam.VariantFile(fn, index_filename=idx_fn) as inf:
+                self.assertEqual(len(list(inf.fetch('20'))), 3)
 
 
 class TestConstructionVCFWithContigs(unittest.TestCase):
@@ -358,7 +457,7 @@ class TestConstructionVCFWithContigs(unittest.TestCase):
     description = 'VCF version 4.2 variant calling text'
 
     def testBase(self):
-        with pysam.VariantFile(os.path.join(DATADIR, self.filename)) as inf:
+        with pysam.VariantFile(os.path.join(CBCF_DATADIR, self.filename)) as inf:
             self.assertEqual(inf.category, 'VARIANTS')
             self.assertEqual(inf.format, 'VCF')
             self.assertEqual(inf.version, (4, 2))
@@ -377,7 +476,7 @@ class TestConstructionVCFWithContigs(unittest.TestCase):
 
     def testConstructionWithRecords(self):
 
-        fn_in = os.path.join(DATADIR, self.filename)
+        fn_in = os.path.join(CBCF_DATADIR, self.filename)
         fn_out = get_temp_filename(suffix=".vcf")
         vcf_in = pysam.VariantFile(fn_in)
 
@@ -400,7 +499,7 @@ class TestConstructionVCFWithContigs(unittest.TestCase):
 
     def testConstructionFromCopy(self):
 
-        fn_in = os.path.join(DATADIR, self.filename)
+        fn_in = os.path.join(CBCF_DATADIR, self.filename)
         fn_out = get_temp_filename(suffix=".vcf")
         vcf_in = pysam.VariantFile(fn_in)
 
@@ -415,7 +514,7 @@ class TestConstructionVCFWithContigs(unittest.TestCase):
 
     def testConstructionWithLines(self):
 
-        fn_in = os.path.join(DATADIR, self.filename)
+        fn_in = os.path.join(CBCF_DATADIR, self.filename)
         fn_out = get_temp_filename(suffix=".vcf")
         vcf_in = pysam.VariantFile(fn_in)
 
@@ -437,7 +536,7 @@ class TestConstructionVCFWithContigs(unittest.TestCase):
         self.complete_check(fn_in, fn_out)
 
 
-#class TestConstructionVCFWithoutContigs(TestConstructionVCFWithContigs):
+# class TestConstructionVCFWithoutContigs(TestConstructionVCFWithContigs):
 #     """construct VariantFile from scratch."""
 #     filename = "example_vcf40.vcf"
 
@@ -463,18 +562,19 @@ class TestSettingRecordValues(unittest.TestCase):
     filename = "example_vcf40.vcf"
 
     def testBase(self):
-        with pysam.VariantFile(os.path.join(DATADIR, self.filename)) as inf:
+        with pysam.VariantFile(os.path.join(CBCF_DATADIR, self.filename)) as inf:
             self.assertEqual(inf.category, 'VARIANTS')
             self.assertEqual(inf.format, 'VCF')
             self.assertEqual(inf.version, (4, 0))
             self.assertEqual(inf.compression, 'NONE')
-            self.assertEqual(inf.description, 'VCF version 4.0 variant calling text')
+            self.assertEqual(
+                inf.description, 'VCF version 4.0 variant calling text')
             self.assertTrue(inf.is_open)
             self.assertEqual(inf.is_read, True)
             self.assertEqual(inf.is_write, False)
 
     def testSetQual(self):
-        with pysam.VariantFile(os.path.join(DATADIR, self.filename)) as inf:
+        with pysam.VariantFile(os.path.join(CBCF_DATADIR, self.filename)) as inf:
             record = next(inf)
             self.assertEqual(record.qual, 47)
             record.qual = record.qual
@@ -484,27 +584,28 @@ class TestSettingRecordValues(unittest.TestCase):
             self.assertEqual(str(record).split("\t")[5], "10")
 
     def testGenotype(self):
-        with pysam.VariantFile(os.path.join(DATADIR, self.filename)) as inf:
+        with pysam.VariantFile(os.path.join(CBCF_DATADIR, self.filename)) as inf:
             record = next(inf)
             sample = record.samples["NA00001"]
-            print (sample["GT"])
+            print(sample["GT"])
             self.assertEqual(sample["GT"], (0, 0))
             sample["GT"] = sample["GT"]
 
+
 class TestSubsetting(unittest.TestCase):
-    
+
     filename = "example_vcf42.vcf.gz"
-    
+
     def testSubsetting(self):
-        with pysam.VariantFile(os.path.join(DATADIR,
+        with pysam.VariantFile(os.path.join(CBCF_DATADIR,
                                             self.filename)) as inf:
             inf.subset_samples(["NA00001"])
 
 
 if __name__ == "__main__":
     # build data files
-    print ("building data files")
-    subprocess.call("make -C %s" % DATADIR, shell=True)
-    print ("starting tests")
+    print("building data files")
+    subprocess.call("make -C %s" % CBCF_DATADIR, shell=True)
+    print("starting tests")
     unittest.main()
-    print ("completed tests")
+    print("completed tests")
